AutocompleteConfig<T> class
Constructors
-
AutocompleteConfig({required Future<
List< fetchItems(String search, int page, int pageSize), required String displayStringForOption(T item), required String getFieldValue(T item, String field), required Map<T> >String, dynamic> convertToMap(T item), required dynamic onSelected(Map<String, dynamic> ), required Map<String, String> fieldLabels, required List<String> fieldOrder, required Map<String, bool> fieldVisibility, required Map<String, int> fieldFlex})
Properties
-
convertToMap
→ Map<
String, dynamic> Function(T item) -
final
- displayStringForOption → String Function(T item)
-
final
-
fetchItems
→ Future<
List< Function(String search, int page, int pageSize)T> > -
final
-
fieldFlex
→ Map<
String, int> -
final
-
fieldLabels
→ Map<
String, String> -
final
-
fieldOrder
→ List<
String> -
final
-
fieldVisibility
→ Map<
String, bool> -
final
- getFieldValue → String Function(T item, String field)
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onSelected
→ dynamic Function(Map<
String, dynamic> ) -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited